@@ -139,6 +139,7 @@ private:
   Lum::Model::BooleanRef        keypad[Sudoku::dimension];
   Lum::Model::BooleanRef        mark;
   bool                          lock;
+  Lum::Images::StatefulImageRef hintImage;
   Lum::Images::StatefulImageRef statisticsImage;
   Lum::Images::StatefulImageRef solveImage;
   Lum::Images::StatefulImageRef generateImage;
@@ -154,6 +155,7 @@ public:
     gameArea(new GameArea()),
     mark(new Lum::Model::Boolean(false)),
     lock(false),
+    hintImage(new Lum::Images::StatefulImage()),
     statisticsImage(new Lum::Images::StatefulImage()),
     solveImage(new Lum::Images::StatefulImage()),
     generateImage(new Lum::Images::StatefulImage())
@@ -178,10 +180,11 @@ public:
     Observe(GetClosedAction());
     Observe(generateTask.GetAbortedAction());
     Observe(generateTask.GetFinishedAction());
-    gameArea->GetFinishedModel()->Off(); // Switch it off initialy and on after config reading!
+    gameArea->GetFinishedModel()->Off();
     Observe(gameArea->GetFocusChangedAction());
     Observe(gameArea->GetFinishedModel());
 
+    Lum::Images::loader->LoadApplication(L"Hint.png",hintImage);
     Lum::Images::loader->LoadApplication(L"Statistics.png",statisticsImage);
     Lum::Images::loader->LoadApplication(L"Solve.png",solveImage);
     Lum::Images::loader->LoadApplication(L"Generate.png",generateImage);
@@ -233,9 +236,21 @@ public:
 
     array=new Lum::Array();
     array->SetFlex(true,false);
-    array->SetHorizontalCount(3);
+    array->SetHorizontalCount(4);
     array->SetSpace(false,false);
 
+    if (hintImage->IsValid()) {
+      Lum::Toggle* toggle=new Lum::Toggle();
+
+      toggle->SetFlex(true,false);
+      toggle->SetModel(gameArea->GetHintMode());
+      toggle->SetLabel(Lum::Image::Create(hintImage));
+
+      array->Add(toggle);
+    }
+    else {
+      array->Add(Lum::Toggle::Create(_(L"GAME_Hint",L"_Hint"),gameArea->GetHintMode(),true,false));
+    }
     if (statisticsImage->IsValid()) {
       array->Add(Lum::Button::Create(Lum::Image::Create(statisticsImage),statAction,true,false));
     }
@@ -388,7 +403,8 @@ public:
       return;
     }
 
-    if (gameArea->GetFinishedModel()->Get() || !gameArea->IsFocusedCellEditable()) {
+    if (gameArea->GetFinishedModel()->Get() ||
+        !gameArea->IsFocusedCellEditable()) {
       // We ignore possible changes if there is no valid game
       return;
     }
@@ -541,16 +557,13 @@ public:
                              L"The interface supports setting numbers and marking\n"
                              L"fields as potentially holding a subset of numbers.\n"
                              L"\n"
-                             L"To mark a field click on the upperleft quadrant. A\n"
-                             L"popup will open, from which you can select/unselect\n"
-                             L"multiple numbers for marking.\n"
-                             L"To set a number, click on any other quadrant. Again\n"
-                             L"a similar dialog will open, this time only allowing\n"
-                             L"one (or no) number.\n"
-                             L"Marks will shown a small numbers, set values as black,\n"
+                             L"Marks will be shown as small numbers, set values as black,\n"
                              L"predefined number will be drawn grey, and conflicts\n"
                              L"red.\n"
                              L"\n"
+                             L"To set/mark a field use the keypad. Explcitely use the mark\n"
+                             L"button to tag an entry as marked.\n"
+                             L"\n"
                              L"Have fun :-)"));
     }
     else if (model==aboutAction &&
